@@ -9,33 +9,32 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.10) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.5.") or
+    raise "ruby lib version (2.5.9) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.4/2.4.0/x86_64-darwin12.0")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.5/2.5.0/x86_64-darwin12.0")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "10"
-  CONFIG["PATCHLEVEL"] = "364"
+  CONFIG["MINOR"] = "5"
+  CONFIG["TEENY"] = "9"
+  CONFIG["PATCHLEVEL"] = "229"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.4"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.4"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.5"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.5"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_PROGRAM_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.4.pc"
+  CONFIG["ruby_pc"] = "ruby-2.5.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
   CONFIG["MANTYPE"] = "doc"
-  CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
@@ -45,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=2.4' '--with-rubylibprefix=/opt/local/lib/ruby2.4' '--with-openssl-include=/opt/local/libexec/openssl11/include' '--with-openssl-lib=/opt/local/libexec/openssl11/lib' 'LIBPATHENV=DYLD_FALLBACK_LIBRARY_PATH' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=2.5' '--with-rubylibprefix=/opt/local/lib/ruby2.5' '--with-openssl-include=/opt/local/libexec/openssl11/include' '--with-openssl-lib=/opt/local/libexec/openssl11/lib' 'LIBPATHENV=DYLD_FALLBACK_LIBRARY_PATH' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +54,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.4.0"
+  CONFIG["ruby_version"] = "2.5.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin12.0"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -86,8 +85,9 @@ module RbConfig
   CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static -framework Foundation"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
-  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_BASE_NAME).$(MAJOR).$(MINOR).dylib lib$(RUBY_INSTALL_NAME).dylib"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).dylib"
+  CONFIG["LIBRUBY_ALIASES"] = "$(LIBRUBY_SONAME) lib$(RUBY_INSTALL_NAME).$(SOEXT)"
+  CONFIG["LIBRUBY_SONAME"] = "lib$(RUBY_BASE_NAME).$(RUBY_API_VERSION).$(SOEXT)"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).$(SOEXT)"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
@@ -96,8 +96,9 @@ module RbConfig
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
-  CONFIG["optflags"] = "-O3 -fno-fast-math"
+  CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
+  CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ""
@@ -107,11 +108,12 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.4"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.5"
   CONFIG["setup"] = "Setup"
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -A -n"
+  CONFIG["SOEXT"] = "dylib"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "DYLD_INSERT_LIBRARIES"
   CONFIG["LIBPATHENV"] = "DYLD_FALLBACK_LIBRARY_PATH"
@@ -129,8 +131,9 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = " -arch x86_64"
   CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names  -arch x86_64 -Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib"
   CONFIG["ALLOCA"] = ""
+  CONFIG["dsymutil"] = "dsymutil"
   CONFIG["codesign"] = "codesign"
-  CONFIG["POSTLINK"] = "test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@"
+  CONFIG["POSTLINK"] = "dsymutil $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
@@ -139,7 +142,6 @@ module RbConfig
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
   CONFIG["PKG_CONFIG"] = "pkg-config"
-  CONFIG["PYTHON"] = ""
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
@@ -173,16 +175,12 @@ module RbConfig
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++"
+  CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector -L/opt/local/lib"
   CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -fno-common"
-  CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["CC"] = "/usr/bin/clang"
-  CONFIG["NACL_LIB_PATH"] = ""
-  CONFIG["NACL_SDK_VARIANT"] = ""
-  CONFIG["NACL_SDK_ROOT"] = ""
-  CONFIG["NACL_TOOLCHAIN"] = ""
   CONFIG["target_os"] = "darwin12.0"
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "x86_64"
@@ -198,7 +196,10 @@ module RbConfig
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "x86_64"
   CONFIG["build"] = "x86_64-apple-darwin12.6.0"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.10"
+  CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.5.9"
+  CONFIG["HAVE_GIT"] = "yes"
+  CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
@@ -230,7 +231,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.4&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&2.5&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -240,8 +241,8 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "9.0.0"
-  CONFIG["SDKROOT"] = ENV["SDKROOT"] || "" # don't run xcrun everytime, usually useless.
+  CONFIG["UNICODE_VERSION"] = "10.0.0"
+  CONFIG["SDKROOT"] = "#{ENV['SDKROOT']}" # don't run xcrun every time, usually useless.
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
